4.55. umbra.ui.widgets.delayed_QSplashScreen — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.55. umbra.ui.widgets.delayed_QSplashScreen

delayed_QSplashScreen.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `Delayed_QSplashScreen` class.

Others:

## 4.55.1. Module Attributes

`umbra.ui.widgets.delayed_QSplashScreen.` `LOGGER`

## 4.55.2. Classes

class `umbra.ui.widgets.delayed_QSplashScreen.` `Delayed_QSplashScreen`(pixmap, waitTime=0, textColor=2, *args, **kwargs)

  Bases: `PyQt4.QtGui.QSplashScreen`

  This class is a QSplashScreen subclass providing delayed messages capabilities.

  Parameters: | pixmap – Current pixmap path. ( String ) waitTime – wait time. ( Integer ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `waitTime`

    This method is the property for self.__waitTime attribute.

    Returns: | self.__waitTime ( Integer / Float )

  `textColor`

    This method is the property for self.__textColor attribute.

    Returns: | self.__textColor ( Integer / QColor )

  `setMessage`(message, textAlignement=1, textColor=None, waitTime=None)

    Parameters: | message – Message to display on the splashscreen. ( String ) textAlignement – Text message alignment. ( Object ) textColor – Text message color. ( Object ) waitTime – Wait time. ( Integer )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »